@@ -1,9 +1,16 @@
 from typing import Optional, List
-
 import flet as ft
 
 
-class LeftView:
+class LeftViewBase:
+    state: dict = {}
+
+    def update_state(self, **new_state):
+        """make changes you need to your components whenever the mutable data updates."""
+        self.state.update(new_state)
+
+
+class LeftView(LeftViewBase):
     @property
     def appbar(self) -> Optional[ft.AppBar]:
         """return how you want the app bar to appear, or None. Called each time the state is updated"""
@@ -30,16 +37,12 @@ class LeftView:
     def bottom_appbar(self) -> Optional[ft.BottomAppBar]:
         return None
 
-    def update_state(self, **new_state):
-        """make changes you need to your components whenever the mutable data updates."""
-        pass
-
     def on_view_removed(self):
         """Called when the view is popped from the stack of page.views"""
         pass
 
 
-class LeftDialog:
+class LeftDialog(LeftViewBase):
     @property
     def title(self) -> ft.Text:
         return ft.Text()
@@ -51,8 +54,3 @@ class LeftDialog:
     @property
     def actions(self) -> List[ft.Container]:
         return []
-
-    def update_state(self, **new_state):
-        """make changes you need to your components whenever the mutable data updates."""
-        pass
-
